Index: gpu/command_buffer/service/gles2_cmd_decoder.h |
diff --git a/gpu/command_buffer/service/gles2_cmd_decoder.h b/gpu/command_buffer/service/gles2_cmd_decoder.h |
index 5ccdf7b96703d7b197574eb36d84f17543df4e72..0cbe0fe586dd6feb095c0268952f1b01c2bd34f1 100644 |
--- a/gpu/command_buffer/service/gles2_cmd_decoder.h |
+++ b/gpu/command_buffer/service/gles2_cmd_decoder.h |
@@ -115,13 +115,13 @@ class GPU_EXPORT GLES2Decoder : public base::SupportsWeakPtr<GLES2Decoder>, |
// offscreen: whether to make the context offscreen or not. When FBO 0 is |
// bound, offscreen contexts render to an internal buffer, onscreen ones |
// to the surface. |
// size: the size if the GL context is offscreen. |
// Returns: |
// true if successful. |
virtual bool Initialize(const scoped_refptr<gfx::GLSurface>& surface, |
const scoped_refptr<gfx::GLContext>& context, |
bool offscreen, |
- const gfx::Size& size, |
+ const gfx::Size& offscreen_size, |
const DisallowedFeatures& disallowed_features, |
const std::vector<int32>& attribs) = 0; |
@@ -115,13 +115,13 @@ class GPU_EXPORT GLES2Decoder : public base::SupportsWeakPtr<GLES2Decoder>, |
// bound, offscreen contexts render to an internal buffer, onscreen ones |
// to the surface. |
- // size: the size if the GL context is offscreen. |
+ // offscreen_size: the size if the GL context is offscreen. |
// Returns: |
// true if successful. |